Crate sp_fragnova

source ·
Helper Functions and Types that are used in other Packages of the this Workspace

Modules

Types that will be used by the Fragments pallet
A runtime interface for the Fragnova Blockchain
Types that will be used by the Protos pallet

Constants

The IPFS CID prefix used to use to obtain any data that is stored on the Fragnova Blockchain

Functions

Returns an account ID that can stake FRAG tokens. This returned account ID is determinstically computed from the given account ID (who).
Get an Account ID deterministically computed from an input hash**.
Make an HTTP POST Request with data body to the URL url
Set the Fragnova-owned Geth Node’s URL

Type Definitions

64 bytes u8-Array
128 bytes u8-Array
256 bytes u8-Array